@@ -1,13 +1,18 @@
 package Net::Amazon::S3::Bucket;
 # ABSTRACT: convenience object for working with Amazon S3 buckets
-$Net::Amazon::S3::Bucket::VERSION = '0.96';
+$Net::Amazon::S3::Bucket::VERSION = '0.98';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use Carp;
 use File::stat;
 use IO::File 1.14;
 
-has 'account' => ( is => 'ro', isa => 'Net::Amazon::S3', required => 1 );
+has 'account' => (
+	is => 'ro',
+	isa => 'Net::Amazon::S3',
+	required => 1,
+	handles => [qw[ err errstr ]],
+);
 has 'bucket'  => ( is => 'ro', isa => 'Str',             required => 1 );
 has 'creation_date' => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 
@@ -24,21 +29,25 @@ __PACKAGE__->meta->make_immutable;
 
 # returns bool
 sub add_key {
-	my ( $self, $key, $value, $conf ) = @_;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_, ['key', 'value']);
+
+	my $key = delete $args{key};
+	my $value = delete $args{value};
 
 	if ( ref($value) eq 'SCALAR' ) {
-		$conf->{'Content-Length'} ||= -s $$value;
+		$args{'Content-Length'} ||= -s $$value;
 		$value = _content_sub($$value);
 	} else {
-		$conf->{'Content-Length'} ||= length $value;
+		$args{'Content-Length'} ||= length $value;
 	}
 
 	my $acl;
-	$acl = delete $conf->{acl_short} if exists $conf->{acl_short};
-	$acl = delete $conf->{acl}       if exists $conf->{acl};
+	$acl = delete $args{acl_short} if exists $args{acl_short};
+	$acl = delete $args{acl}       if exists $args{acl};
 
-	my $encryption = delete $conf->{encryption};
-	my %headers = %$conf;
+	my $encryption = delete $args{encryption};
+	my %headers = %args;
 
 	# we may get a 307 redirect; ask server to signal 100 Continue
 	# before reading the content from CODE reference (_content_sub)
@@ -58,78 +67,100 @@ sub add_key {
 }
 
 sub add_key_filename {
-	my ( $self, $key, $value, $conf ) = @_;
-	return $self->add_key( $key, \$value, $conf );
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_, ['key', 'value']);
+	$args{value} = \ delete $args{value};
+
+	return $self->add_key (%args);
 }
 
 sub copy_key {
-	my ( $self, $key, $source, $conf ) = @_;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_, ['key', 'source' ]);
+
+	my $key = delete $args{key};
+	my $source = delete $args{source};
 
 	my $acl_short;
-	if ( defined $conf ) {
-		if ( $conf->{acl_short} ) {
-			$acl_short = $conf->{acl_short};
-			delete $conf->{acl_short};
+	if (%args) {
+		if ( $args{acl_short} ) {
+			$acl_short = $args{acl_short};
+			delete $args{acl_short};
 		}
-		$conf->{Net::Amazon::S3::Constants->HEADER_METADATA_DIRECTIVE} ||= 'REPLACE';
-	} else {
-		$conf = {};
+		$args{Net::Amazon::S3::Constants->HEADER_METADATA_DIRECTIVE} ||= 'REPLACE';
 	}
 
-	$conf->{Net::Amazon::S3::Constants->HEADER_COPY_SOURCE} = $source;
+	$args{Net::Amazon::S3::Constants->HEADER_COPY_SOURCE} = $source;
 
-	my $encryption = delete $conf->{encryption};
+	my $encryption = delete $args{encryption};
 
 	my $acct    = $self->account;
 	my $response = $self->_perform_operation (
 		'Net::Amazon::S3::Operation::Object::Add',
 
-		key       => $key,
 		value     => '',
+		key       => $key,
 		acl_short => $acl_short,
 		(encryption => $encryption) x!! defined $encryption,
-		headers   => $conf,
+		headers   => \%args,
 	);
 
 	return unless $response->is_success;
 }
 
 sub edit_metadata {
-	my ( $self, $key, $conf ) = @_;
-	croak "Need configuration hash" unless defined $conf;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments_with_object (\@_);
 
-	return $self->copy_key( $key, "/" . $self->bucket . "/" . $key, $conf );
+	my $key = delete $args{key};
+	croak "Need some metadata to change" unless %args;
+
+	return $self->copy_key (
+		key    => $key,
+		source => "/" . $self->bucket . "/" . $key,
+		%args,
+	);
 }
 
 sub head_key {
-	my ( $self, $key ) = @_;
-	return $self->get_key( $key, "HEAD" );
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments_with_object (\@_);
+
+	return $self->get_key (%args, method => 'HEAD', filename => undef);
 }
 
 sub query_string_authentication_uri {
-	my ( $self, $key, $expires_at ) = @_;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_, ['key', 'expires_at']);
+
+	$args{method} = 'GET' unless exists $args{method};
 
 	my $request = Net::Amazon::S3::Operation::Object::Fetch::Request->new (
 		s3     => $self->account,
 		bucket => $self,
-		key    => $key,
-		method => 'GET',
+		key    => $args{key},
+		method => $args{method},
 	);
 
-	return $request->query_string_authentication_uri ($expires_at);
+	return $request->query_string_authentication_uri ($args{expires_at});
 }
 
 sub get_key {
-	my ( $self, $key, $method, $filename ) = @_;
-	$filename = $$filename if ref $filename;
-	my $acct = $self->account;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_, ['key', 'method', 'filename']);
+
+	$args{filename} = ${ delete $args{filename} }
+		if ref $args{filename};
+
+	$args{method} ||= 'GET';
 
 	my $response = $self->_perform_operation (
 		'Net::Amazon::S3::Operation::Object::Fetch',
-		filename => $filename,
 
-		key    => $key,
-		method => $method || 'GET',
+		filename => $args{filename},
+
+		key    => $args{key},
+		method => $args{method},
 	);
 
 	return unless $response->is_success;
@@ -149,8 +180,11 @@ sub get_key {
 }
 
 sub get_key_filename {
-	my ( $self, $key, $method, $filename ) = @_;
-	return $self->get_key( $key, $method, \$filename );
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_, ['key', 'method', 'filename']);
+
+	$args{filename} = \ delete $args{filename};
+	return $self->get_key (%args);
 }
 
 # returns bool
@@ -180,13 +214,14 @@ sub delete_multi_object {
 }
 
 sub delete_key {
-	my ( $self, $key ) = @_;
-	croak 'must specify key' unless defined $key && length $key;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments_with_object (\@_);
+
+	croak 'must specify key' unless defined $args{key} && length $args{key};
 
 	my $response = $self->_perform_operation (
 		'Net::Amazon::S3::Operation::Object::Delete',
-
-		key    => $key,
+		%args,
 	);
 
 	return $response->is_success;
@@ -194,37 +229,38 @@ sub delete_key {
 
 sub delete_bucket {
 	my $self = shift;
-	croak "Unexpected arguments" if @_;
-	return $self->account->delete_bucket($self);
+	return $self->account->delete_bucket (bucket => $self, @_);
 }
 
 sub list {
 	my $self = shift;
-	my $conf = shift || {};
-	$conf->{bucket} = $self->bucket;
-	return $self->account->list_bucket($conf);
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_);
+
+	return $self->account->list_bucket ($self, %args);
 }
 
 sub list_all {
 	my $self = shift;
-	my $conf = shift || {};
-	$conf->{bucket} = $self->bucket;
-	return $self->account->list_bucket_all($conf);
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_);
+
+	return $self->account->list_bucket_all ($self, %args);
 }
 
 sub get_acl {
-	my ($self, $key) = @_;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments_with_object (\@_);
 
 	my $response;
-	if ($key) {
+	if (defined $args{key}) {
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Object::Acl::Fetch',
-
-			key    => $key,
+			%args,
 		);
 	} else {
+		delete $args{key};
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Bucket::Acl::Fetch',
+			%args,
 		);
 	}
 
@@ -233,27 +269,20 @@ sub get_acl {
 }
 
 sub set_acl {
-	my ( $self, $conf ) = @_;
-	$conf ||= {};
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments_with_object (\@_);
 
 	my $response;
-	my $key = $conf->{key};
-	if ($key) {
+	if (defined $args{key}) {
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Object::Acl::Set',
-
-			key       => $key,
-			(acl       => $conf->{acl})       x!! defined $conf->{acl},
-			(acl_short => $conf->{acl_short}) x!! defined $conf->{acl_short},
-			(acl_xml   => $conf->{acl_xml})   x!! defined $conf->{acl_xml},
+			%args,
 		);
 	} else {
+		delete $args{key};
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Bucket::Acl::Set',
-
-			(acl       => $conf->{acl})       x!! defined $conf->{acl},
-			(acl_short => $conf->{acl_short}) x!! defined $conf->{acl_short},
-			(acl_xml   => $conf->{acl_xml})   x!! defined $conf->{acl_xml},
+			%args,
 		);
 	}
 
@@ -262,39 +291,33 @@ sub set_acl {
 }
 
 sub get_location_constraint {
-	my ($self) = @_;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments (\@_);
 
 	my $response = $self->_perform_operation (
 		'Net::Amazon::S3::Operation::Bucket::Location',
+		%args,
 	);
 
 	return unless $response->is_success;
 	return $response->location;
 }
 
-# proxy up the err requests
-
-sub err { $_[0]->account->err }
-
-sub errstr { $_[0]->account->errstr }
-
 sub add_tags {
-	my ($self, $conf) = @_;
+	my $self = shift;
+	my %args = @_ == 1 ? %{ $_[0] } : @_;
 
 	my $response;
-	if (exists $conf->{key}) {
+	if (defined $args{key}) {
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Object::Tags::Add',
-
-			tags   => $conf->{tags},
-			key    => $conf->{key},
-			(version_id => $conf->{version_id}) x!! defined $conf->{version_id},
+			%args,
 		);
 	} else {
+		delete $args{key};
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Bucket::Tags::Add',
-
-			tags   => $conf->{tags},
+			%args,
 		);
 	}
 
@@ -302,19 +325,20 @@ sub add_tags {
 }
 
 sub delete_tags {
-	my ($self, $conf) = @_;
+	my $self = shift;
+	my %args = Net::Amazon::S3::Utils->parse_arguments_with_object (\@_);
 
 	my $response;
-	if (exists $conf->{key}) {
+	if (defined $args{key}) {
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Object::Tags::Delete',
-
-			key    => $conf->{key},
-			(version_id => $conf->{version_id}) x!! defined $conf->{version_id},
+			%args,
 		);
 	} else {
+		delete $args{key};
 		$response = $self->_perform_operation (
 			'Net::Amazon::S3::Operation::Bucket::Tags::Delete',
+			%args,
 		);
 	}
 
@@ -423,7 +447,7 @@ Net::Amazon::S3::Bucket - convenience object for working with Amazon S3 buckets
 
 =head1 VERSION
 
-version 0.96
+version 0.98
 
 =head1 SYNOPSIS
 
@@ -584,8 +608,53 @@ Takes the name of a key in this bucket and returns its configuration hash
 
 =head2 query_string_authentication_uri KEY, EXPIRES_AT
 
-Takes key and expiration time (epoch time) and returns uri signed
-with query parameter
+	my $uri = $bucket->query_string_authentication_uri (
+		key => 'foo',
+		expires_at => time + 3_600, # valid for one hour
+	);
+
+	my $uri = $bucket->query_string_authentication_uri (
+		key => 'foo',
+		expires_at => time + 3_600,
+		method => 'PUT',
+	);
+
+Returns uri presigned with your credentials.
+
+When used with Signature V4 you have to specify also HTTP method this
+presigned uri will be used for (default: C<GET>)
+
+Method provides authenticated uri only for direct object operations.
+
+Method follows API's L</"CALLING CONVENTION">.
+
+Recognized positional arguments (mandatory).
+
+=over
+
+=item key
+
+=item expires_at
+
+Expiration time (epoch time).
+
+=back
+
+Optional arguments
+
+=over
+
+=item method
+
+Default: C<GET>
+
+Intended HTTP method this uri will be presigned for.
+
+Signature V2 doesn't use it but Signature V4 does.
+
+See L<https://docs.aws.amazon.com/AmazonS3/latest/dev/PresignedUrlUploadObject.html>
+
+=back
 
 =head2 get_key $key_name [$method]
 
@@ -789,7 +858,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
