@@ -1,6 +1,6 @@
 package Shared::Examples::Net::Amazon::S3::Client;
 # ABSTRACT: used for testing and as example
-$Shared::Examples::Net::Amazon::S3::Client::VERSION = '0.97';
+$Shared::Examples::Net::Amazon::S3::Client::VERSION = '0.98';
 use strict;
 use warnings;
 
@@ -31,6 +31,7 @@ our @EXPORT_OK = (
 	qw[ expect_client_object_create ],
 	qw[ expect_client_object_delete ],
 	qw[ expect_client_object_fetch ],
+	qw[ expect_client_object_head ],
 	qw[ expect_client_object_tags_add],
 	qw[ expect_client_object_tags_delete],
 );
@@ -207,6 +208,16 @@ sub operation_object_fetch {
 		;
 }
 
+sub operation_object_head {
+	my ($self, %params) = @_;
+
+	$self
+		->bucket (name => $params{with_bucket})
+		->object (key => $params{with_key})
+		->exists
+		;
+}
+
 sub operation_bucket_acl_set {
 	my ($self, %params) = @_;
 
@@ -293,7 +304,7 @@ Shared::Examples::Net::Amazon::S3::Client - used for testing and as example
 
 =head1 VERSION
 
-version 0.97
+version 0.98
 
 =head1 AUTHOR
 
@@ -301,7 +312,7 @@ Branislav Zahradník <barney@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
+This software is copyright (c) 2021 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
